@@ -62,7 +62,7 @@ class OpenEVSE:
             _LOGGER.debug("JSON error: %s", value.text)
             raise ParseJSONError
         if value.status_code == 401:
-            _LOGGER.debug("Authentication error: %s", value.text)
+            _LOGGER.debug("Authentication error: %s", value)
             raise AuthenticationError
 
         if "ret" not in value.json():
@@ -82,7 +82,7 @@ class OpenEVSE:
                 value = requests.get(url)
 
             if value.status_code == 401:
-                _LOGGER.debug("Authentication error: %s", value.text)
+                _LOGGER.debug("Authentication error: %s", value)
                 raise AuthenticationError
 
             if "/status" in url:
